Enums
- SqlValue
- Represents a SQL value that can be used across different database drivers
Functions
- escape_
column_ name - escape_
table_ name - execute_
query - Execute a single SQL query with parameters (for seeder tracking)
- query_
single_ int - Execute a query that returns a single integer result (for counting)
- query_
single_ text - Execute a query and return the first column of the first row as text
- run_
seeder